@@ -109,27 +109,27 @@ PG_FUNCTION_INFO_V1(utl_file_tmpdir);
 
 typedef struct FileSlot
 {
-	FILE   *file;
-	int		max_linesize;
-	int		encoding;
-	int32	id;
+	FILE	   *file;
+	int			max_linesize;
+	int			encoding;
+	int32		id;
 } FileSlot;
 
-#define MAX_SLOTS		50			/* Oracle 10g supports 50 files */
-#define INVALID_SLOTID	0			/* invalid slot id */
+#define MAX_SLOTS		50		/* Oracle 10g supports 50 files */
+#define INVALID_SLOTID	0		/* invalid slot id */
 
-static FileSlot	slots[MAX_SLOTS];	/* initilaized with zeros */
-static int32	slotid = 0;			/* next slot id */
+static FileSlot slots[MAX_SLOTS];	/* initilaized with zeros */
+static int32 slotid = 0;		/* next slot id */
 
 static void check_secure_locality(const char *path);
 static char *get_safe_path(text *location, text *filename);
-static int copy_text_file(FILE *srcfile, FILE *dstfile,
-						  int start_line, int end_line);
+static int	copy_text_file(FILE *srcfile, FILE *dstfile,
+						   int start_line, int end_line);
 
-static int orafce_umask = 077;
-char *orafce_umask_str = NULL;
+static int	orafce_umask = 077;
+char	   *orafce_umask_str = NULL;
 
-static Oid orafce_set_umask_roleid = InvalidOid;
+static Oid	orafce_set_umask_roleid = InvalidOid;
 
 void
 orafce_umask_assign_hook(const char *newvalue, void *extra)
@@ -208,7 +208,7 @@ orafce_umask_check_hook(char **newval, void **extra, GucSource source)
 static int
 get_descriptor(FILE *file, int max_linesize, int encoding)
 {
-	int i;
+	int			i;
 
 	for (i = 0; i < MAX_SLOTS; i++)
 	{
@@ -216,7 +216,7 @@ get_descriptor(FILE *file, int max_linesize, int encoding)
 		{
 			slots[i].id = ++slotid;
 			if (slots[i].id == INVALID_SLOTID)
-				slots[i].id = ++slotid;	/* skip INVALID_SLOTID */
+				slots[i].id = ++slotid; /* skip INVALID_SLOTID */
 			slots[i].file = file;
 			slots[i].max_linesize = max_linesize;
 			slots[i].encoding = encoding;
@@ -231,7 +231,7 @@ get_descriptor(FILE *file, int max_linesize, int encoding)
 static FILE *
 get_stream(int d, size_t *max_linesize, int *encoding)
 {
-	int i;
+	int			i;
 
 	if (d == INVALID_SLOTID)
 		INVALID_FILEHANDLE_EXCEPTION();
@@ -249,7 +249,7 @@ get_stream(int d, size_t *max_linesize, int *encoding)
 	}
 
 	INVALID_FILEHANDLE_EXCEPTION();
-	return NULL;	/* keep compiler quiet */
+	return NULL;				/* keep compiler quiet */
 }
 
 static void
@@ -282,7 +282,7 @@ static wchar_t *
 to_wchar(const char *str)
 {
 	size_t		nbytes;
-	wchar_t	   *buff;
+	wchar_t    *buff;
 
 	nbytes = strlen(str);
 
@@ -341,11 +341,12 @@ utl_file_fopen(PG_FUNCTION_ARGS)
 	if (PG_NARGS() > 4 && !PG_ARGISNULL(4))
 	{
 		const char *encname = NameStr(*PG_GETARG_NAME(4));
+
 		encoding = pg_char_to_encoding(encname);
 		if (encoding < 0)
 			ereport(ERROR,
-				(errcode(ERRCODE_INVALID_PARAMETER_VALUE),
-				 errmsg("invalid encoding name \"%s\"", encname)));
+					(errcode(ERRCODE_INVALID_PARAMETER_VALUE),
+					 errmsg("invalid encoding name \"%s\"", encname)));
 	}
 	else
 		encoding = GetDatabaseEncoding();
@@ -353,7 +354,7 @@ utl_file_fopen(PG_FUNCTION_ARGS)
 	if (VARSIZE(open_mode) - VARHDRSZ != 1)
 		CUSTOM_EXCEPTION(INVALID_MODE, "open mode is different than [R,W,A]");
 
-	switch (*((char*)VARDATA(open_mode)))
+	switch (*((char *) VARDATA(open_mode)))
 	{
 		case 'a':
 		case 'A':
@@ -393,8 +394,8 @@ utl_file_fopen(PG_FUNCTION_ARGS)
 
 	if (pg_database_encoding_max_length() > 1)
 	{
-		wchar_t	   *_fullname = to_wchar(fullname);
-		wchar_t	   *_mode = to_wchar(mode);
+		wchar_t    *_fullname = to_wchar(fullname);
+		wchar_t    *_mode = to_wchar(mode);
 
 		file = _wfopen(_fullname, _mode);
 
@@ -416,10 +417,10 @@ utl_file_fopen(PG_FUNCTION_ARGS)
 	{
 		fclose(file);
 		ereport(ERROR,
-		    (errcode(ERRCODE_PROGRAM_LIMIT_EXCEEDED),
-		     errmsg("program limit exceeded"),
-		     errdetail("Too many files opened concurrently"),
-		     errhint("You can only open a maximum of ten files for each session")));
+				(errcode(ERRCODE_PROGRAM_LIMIT_EXCEEDED),
+				 errmsg("program limit exceeded"),
+				 errdetail("Too many files opened concurrently"),
+				 errhint("You can only open a maximum of ten files for each session")));
 	}
 
 	PG_RETURN_INT32(d);
@@ -430,8 +431,8 @@ utl_file_is_open(PG_FUNCTION_ARGS)
 {
 	if (!PG_ARGISNULL(0))
 	{
-		int	i;
-		int	d = PG_GETARG_INT32(0);
+		int			i;
+		int			d = PG_GETARG_INT32(0);
 
 		for (i = 0; i < MAX_SLOTS; i++)
 		{
@@ -452,12 +453,12 @@ utl_file_is_open(PG_FUNCTION_ARGS)
 static text *
 get_line(FILE *f, size_t max_linesize, int encoding, bool *iseof)
 {
-	int c;
-	char *buffer = NULL;
-	char *bpt;
-	size_t csize = 0;
-	text *result = NULL;
-	bool eof = true;
+	int			c;
+	char	   *buffer = NULL;
+	char	   *bpt;
+	size_t		csize = 0;
+	text	   *result = NULL;
+	bool		eof = true;
 
 	buffer = palloc(max_linesize + 2);
 	bpt = buffer;
@@ -466,13 +467,13 @@ get_line(FILE *f, size_t max_linesize, int encoding, bool *iseof)
 
 	while (csize < max_linesize && (c = fgetc(f)) != EOF)
 	{
-		eof = false; 	/* I was able read one char */
+		eof = false;			/* I was able read one char */
 
-		if (c == '\r')  /* lookin ahead \n */
+		if (c == '\r')			/* lookin ahead \n */
 		{
 			c = fgetc(f);
 			if (c == EOF)
-				break;  /* last char */
+				break;			/* last char */
 
 			if (c != '\n')
 				ungetc(c, f);
@@ -488,12 +489,12 @@ get_line(FILE *f, size_t max_linesize, int encoding, bool *iseof)
 
 	if (!eof)
 	{
-		char   *decoded;
+		char	   *decoded;
 		size_t		len;
 
 		pg_verify_mbstr(encoding, buffer, size2int(csize), false);
 		decoded = (char *) pg_do_encoding_conversion((unsigned char *) buffer,
-									 size2int(csize), encoding, GetDatabaseEncoding());
+													 size2int(csize), encoding, GetDatabaseEncoding());
 		len = (decoded == buffer ? csize : strlen(decoded));
 		result = palloc(len + VARHDRSZ);
 		memcpy(VARDATA(result), decoded, len);
@@ -537,11 +538,11 @@ get_line(FILE *f, size_t max_linesize, int encoding, bool *iseof)
 Datum
 utl_file_get_line(PG_FUNCTION_ARGS)
 {
-	size_t	max_linesize = 0;	/* keep compiler quiet */
-	int		encoding = 0;		/* keep compiler quiet */
-	FILE   *f;
-	text   *result;
-	bool	iseof;
+	size_t		max_linesize = 0;	/* keep compiler quiet */
+	int			encoding = 0;	/* keep compiler quiet */
+	FILE	   *f;
+	text	   *result;
+	bool		iseof;
 
 	CHECK_FILE_HANDLE();
 	f = get_stream(PG_GETARG_INT32(0), &max_linesize, &encoding);
@@ -549,7 +550,8 @@ utl_file_get_line(PG_FUNCTION_ARGS)
 	/* 'len' overwrites max_linesize, but must be smaller than max_linesize */
 	if (PG_NARGS() > 1 && !PG_ARGISNULL(1))
 	{
-		size_t	len = (size_t) PG_GETARG_INT32(1);
+		size_t		len = (size_t) PG_GETARG_INT32(1);
+
 		CHECK_LINESIZE(len);
 		if (max_linesize > len)
 			max_linesize = len;
@@ -558,9 +560,9 @@ utl_file_get_line(PG_FUNCTION_ARGS)
 	result = get_line(f, max_linesize, encoding, &iseof);
 
 	if (iseof)
-	    	ereport(ERROR,
+		ereport(ERROR,
 				(errcode(ERRCODE_NO_DATA_FOUND),
-		    		 errmsg("no data found")));
+				 errmsg("no data found")));
 
 	PG_RETURN_TEXT_P(result);
 }
@@ -578,11 +580,11 @@ utl_file_get_line(PG_FUNCTION_ARGS)
 Datum
 utl_file_get_nextline(PG_FUNCTION_ARGS)
 {
-	size_t	max_linesize = 0;		/* keep compiler quiet */
-	int		encoding = 0;			/* keep compiler quiet */
-	FILE   *f;
-	text   *result;
-	bool	iseof;
+	size_t		max_linesize = 0;	/* keep compiler quiet */
+	int			encoding = 0;	/* keep compiler quiet */
+	FILE	   *f;
+	text	   *result;
+	bool		iseof;
 
 	CHECK_FILE_HANDLE();
 	f = get_stream(PG_GETARG_INT32(0), &max_linesize, &encoding);
@@ -638,7 +640,7 @@ encode_text(int encoding, text *t, size_t *length)
 	char	   *encoded;
 
 	encoded = (char *) pg_do_encoding_conversion((unsigned char *) src,
-					VARSIZE_ANY_EXHDR(t), GetDatabaseEncoding(), encoding);
+												 VARSIZE_ANY_EXHDR(t), GetDatabaseEncoding(), encoding);
 
 	*length = (src == encoded ? VARSIZE_ANY_EXHDR(t) : strlen(encoded));
 	return encoded;
@@ -650,7 +652,7 @@ do_write(PG_FUNCTION_ARGS, int n, FILE *f, size_t max_linesize, int encoding)
 {
 	text	   *arg = PG_GETARG_TEXT_P(n);
 	char	   *str;
-	size_t			len;
+	size_t		len;
 
 	str = encode_text(encoding, arg, &len);
 	CHECK_LENGTH(len);
@@ -668,9 +670,9 @@ do_write(PG_FUNCTION_ARGS, int n, FILE *f, size_t max_linesize, int encoding)
 static FILE *
 do_put(PG_FUNCTION_ARGS)
 {
-	FILE   *f;
-	size_t	max_linesize = 0;		/* keep compiler quiet */
-	int		encoding = 0;			/* keep compiler quiet */
+	FILE	   *f;
+	size_t		max_linesize = 0;	/* keep compiler quiet */
+	int			encoding = 0;	/* keep compiler quiet */
 
 	CHECK_FILE_HANDLE();
 	f = get_stream(PG_GETARG_INT32(0), &max_linesize, &encoding);
@@ -690,15 +692,16 @@ utl_file_put(PG_FUNCTION_ARGS)
 static void
 do_new_line(FILE *f, int lines)
 {
-	int	i;
+	int			i;
+
 	for (i = 0; i < lines; i++)
 	{
 #ifndef WIN32
 		if (fputc('\n', f) == EOF)
-		    CHECK_ERRNO_PUT();
+			CHECK_ERRNO_PUT();
 #else
 		if (fputs("\r\n", f) == EOF)
-		    CHECK_ERRNO_PUT();
+			CHECK_ERRNO_PUT();
 #endif
 	}
 }
@@ -706,8 +709,8 @@ do_new_line(FILE *f, int lines)
 Datum
 utl_file_put_line(PG_FUNCTION_ARGS)
 {
-	FILE   *f;
-	bool	autoflush;
+	FILE	   *f;
+	bool		autoflush;
 
 	f = do_put(fcinfo);
 
@@ -724,8 +727,8 @@ utl_file_put_line(PG_FUNCTION_ARGS)
 Datum
 utl_file_new_line(PG_FUNCTION_ARGS)
 {
-	FILE   *f;
-	int		lines;
+	FILE	   *f;
+	int			lines;
 
 	CHECK_FILE_HANDLE();
 	f = get_stream(PG_GETARG_INT32(0), NULL, NULL);
@@ -754,14 +757,14 @@ utl_file_new_line(PG_FUNCTION_ARGS)
 Datum
 utl_file_putf(PG_FUNCTION_ARGS)
 {
-	FILE   *f;
-	char   *format;
-	size_t	max_linesize;
-	int		encoding;
-	size_t	format_length;
-	char   *fpt;
-	int		cur_par = 0;
-	size_t	cur_len = 0;
+	FILE	   *f;
+	char	   *format;
+	size_t		max_linesize;
+	int			encoding;
+	size_t		format_length;
+	char	   *fpt;
+	int			cur_par = 0;
+	size_t		cur_len = 0;
 
 	CHECK_FILE_HANDLE();
 	f = get_stream(PG_GETARG_INT32(0), &max_linesize, &encoding);
@@ -785,7 +788,8 @@ utl_file_putf(PG_FUNCTION_ARGS)
 			CHECK_LENGTH(++cur_len);
 			if (fputc('\n', f) == EOF)
 				CHECK_ERRNO_PUT();
-			fpt++; format_length--;
+			fpt++;
+			format_length--;
 			continue;
 		}
 		if (fpt[0] == '%')
@@ -800,7 +804,8 @@ utl_file_putf(PG_FUNCTION_ARGS)
 			{
 				cur_len += do_write(fcinfo, cur_par + 1, f, max_linesize - cur_len, encoding);
 			}
-			fpt++; format_length--;
+			fpt++;
+			format_length--;
 			continue;
 		}
 		CHECK_LENGTH(++cur_len);
@@ -824,7 +829,7 @@ utl_file_putf(PG_FUNCTION_ARGS)
 Datum
 utl_file_fflush(PG_FUNCTION_ARGS)
 {
-	FILE *f;
+	FILE	   *f;
 
 	CHECK_FILE_HANDLE();
 	f = get_stream(PG_GETARG_INT32(0), NULL, NULL);
@@ -848,14 +853,14 @@ utl_file_fflush(PG_FUNCTION_ARGS)
 Datum
 utl_file_fclose(PG_FUNCTION_ARGS)
 {
-	int i;
-	int	d = PG_GETARG_INT32(0);
+	int			i;
+	int			d = PG_GETARG_INT32(0);
 
 	for (i = 0; i < MAX_SLOTS; i++)
 	{
 		if (slots[i].id == d)
 		{
-			FILE *f = slots[i].file;
+			FILE	   *f = slots[i].file;
 
 			slots[i].file = NULL;
 			slots[i].id = INVALID_SLOTID;
@@ -887,13 +892,13 @@ utl_file_fclose(PG_FUNCTION_ARGS)
 Datum
 utl_file_fclose_all(PG_FUNCTION_ARGS)
 {
-	int i;
+	int			i;
 
 	for (i = 0; i < MAX_SLOTS; i++)
 	{
 		if (slots[i].id != INVALID_SLOTID)
 		{
-			FILE *f = slots[i].file;
+			FILE	   *f = slots[i].file;
 
 			slots[i].file = NULL;
 			slots[i].id = INVALID_SLOTID;
@@ -919,70 +924,67 @@ utl_file_fclose_all(PG_FUNCTION_ARGS)
 static void
 check_secure_locality(const char *path)
 {
-	static SPIPlanPtr	plan = NULL;
+	static SPIPlanPtr plan = NULL;
 
-	Datum	values[1];
-	char	nulls[1] = {' '};
+	Datum		values[1];
+	char		nulls[1] = {' '};
 
 	values[0] = CStringGetTextDatum(path);
 
 	/*
-	 * SELECT 1 FROM utl_file.utl_file_dir
-	 *   WHERE CASE WHEN substring(dir from '.$') = '/' THEN
-	 *     substring($1, 1, length(dir)) = dir
-	 *   ELSE
-	 *     substring($1, 1, length(dir) + 1) = dir || '/'
-	 *   END
+	 * SELECT 1 FROM utl_file.utl_file_dir WHERE CASE WHEN substring(dir from
+	 * '.$') = '/' THEN substring($1, 1, length(dir)) = dir ELSE substring($1,
+	 * 1, length(dir) + 1) = dir || '/' END
 	 */
 
 	if (SPI_connect() < 0)
 		ereport(ERROR,
-			(errcode(ERRCODE_INTERNAL_ERROR),
-			 errmsg("SPI_connect failed")));
+				(errcode(ERRCODE_INTERNAL_ERROR),
+				 errmsg("SPI_connect failed")));
 
 	if (!plan)
 	{
-		Oid		argtypes[] = {TEXTOID};
+		Oid			argtypes[] = {TEXTOID};
 
 		/* Don't use LIKE not to escape '_' and '%' */
-		SPIPlanPtr p = SPI_prepare(
-		    "SELECT 1 FROM utl_file.utl_file_dir"
-	 	        " WHERE CASE WHEN substring(dir from '.$') = '/' THEN"
-	 	        "  substring($1, 1, length(dir)) = dir"
-	 	        " ELSE"
-	 	        "  substring($1, 1, length(dir) + 1) = dir || '/'"
-	 	        " END",
-		    1, argtypes);
+		SPIPlanPtr	p = SPI_prepare(
+									"SELECT 1 FROM utl_file.utl_file_dir"
+									" WHERE CASE WHEN substring(dir from '.$') = '/' THEN"
+									"  substring($1, 1, length(dir)) = dir"
+									" ELSE"
+									"  substring($1, 1, length(dir) + 1) = dir || '/'"
+									" END",
+									1, argtypes);
 
 		if (p == NULL || (plan = SPI_saveplan(p)) == NULL)
 			ereport(ERROR,
-				(errcode(ERRCODE_INTERNAL_ERROR),
-				errmsg("SPI_prepare_failed")));
+					(errcode(ERRCODE_INTERNAL_ERROR),
+					 errmsg("SPI_prepare_failed")));
 	}
 
 	if (SPI_OK_SELECT != SPI_execute_plan(plan, values, nulls, false, 1))
 		ereport(ERROR,
-			(errcode(ERRCODE_INTERNAL_ERROR),
-			 errmsg("can't execute sql")));
+				(errcode(ERRCODE_INTERNAL_ERROR),
+				 errmsg("can't execute sql")));
 
 	if (SPI_processed == 0)
 		ereport(ERROR,
-			(errcode(ERRCODE_RAISE_EXCEPTION),
-			 errmsg(INVALID_PATH),
-			 errdetail("you cannot access locality"),
-			 errhint("locality is not found in utl_file_dir table")));
+				(errcode(ERRCODE_RAISE_EXCEPTION),
+				 errmsg(INVALID_PATH),
+				 errdetail("you cannot access locality"),
+				 errhint("locality is not found in utl_file_dir table")));
 	SPI_finish();
 }
 
 static char *
 safe_named_location(text *location)
 {
-	static SPIPlanPtr	plan = NULL;
-	MemoryContext		old_cxt;
+	static SPIPlanPtr plan = NULL;
+	MemoryContext old_cxt;
 
-	Datum	values[1];
-	char	nulls[1] = {' '};
-	char   *result;
+	Datum		values[1];
+	char		nulls[1] = {' '};
+	char	   *result;
 
 	old_cxt = CurrentMemoryContext;
 
@@ -990,33 +992,34 @@ safe_named_location(text *location)
 
 	if (SPI_connect() < 0)
 		ereport(ERROR,
-			(errcode(ERRCODE_INTERNAL_ERROR),
-			 errmsg("SPI_connect failed")));
+				(errcode(ERRCODE_INTERNAL_ERROR),
+				 errmsg("SPI_connect failed")));
 
 	if (!plan)
 	{
-		Oid		argtypes[] = {TEXTOID};
+		Oid			argtypes[] = {TEXTOID};
 
 		/* Don't use LIKE not to escape '_' and '%' */
-		SPIPlanPtr p = SPI_prepare(
-		    "SELECT dir FROM utl_file.utl_file_dir WHERE dirname = $1",
-		    1, argtypes);
+		SPIPlanPtr	p = SPI_prepare(
+									"SELECT dir FROM utl_file.utl_file_dir WHERE dirname = $1",
+									1, argtypes);
 
 		if (p == NULL || (plan = SPI_saveplan(p)) == NULL)
 			ereport(ERROR,
-				(errcode(ERRCODE_INTERNAL_ERROR),
-				errmsg("SPI_prepare_failed")));
+					(errcode(ERRCODE_INTERNAL_ERROR),
+					 errmsg("SPI_prepare_failed")));
 	}
 
 	if (SPI_OK_SELECT != SPI_execute_plan(plan, values, nulls, false, 1))
 		ereport(ERROR,
-			(errcode(ERRCODE_INTERNAL_ERROR),
-			 errmsg("can't execute sql")));
+				(errcode(ERRCODE_INTERNAL_ERROR),
+				 errmsg("can't execute sql")));
 
 	if (SPI_processed > 0)
 	{
 		char	   *loc = SPI_getvalue(SPI_tuptable->vals[0],
 									   SPI_tuptable->tupdesc, 1);
+
 		if (loc)
 			result = MemoryContextStrdup(old_cxt, loc);
 		else
@@ -1048,8 +1051,8 @@ get_safe_path(text *location_or_dirname, text *filename)
 	location = safe_named_location(location_or_dirname);
 	if (location)
 	{
-		int		aux_pos = size2int(strlen(location));
-		int		aux_len = VARSIZE_ANY_EXHDR(filename);
+		int			aux_pos = size2int(strlen(location));
+		int			aux_len = VARSIZE_ANY_EXHDR(filename);
 
 		fullname = palloc(aux_pos + 1 + aux_len + 1);
 		strcpy(fullname, location);
@@ -1063,8 +1066,8 @@ get_safe_path(text *location_or_dirname, text *filename)
 	}
 	else
 	{
-		int aux_pos = VARSIZE_ANY_EXHDR(location_or_dirname);
-		int aux_len = VARSIZE_ANY_EXHDR(filename);
+		int			aux_pos = VARSIZE_ANY_EXHDR(location_or_dirname);
+		int			aux_len = VARSIZE_ANY_EXHDR(filename);
 
 		fullname = palloc(aux_pos + 1 + aux_len + 1);
 		memcpy(fullname, VARDATA(location_or_dirname), aux_pos);
@@ -1108,7 +1111,7 @@ utl_file_fremove(PG_FUNCTION_ARGS)
 
 	if (pg_database_encoding_max_length() > 1)
 	{
-		wchar_t	   *_fullname = to_wchar(fullname);
+		wchar_t    *_fullname = to_wchar(fullname);
 
 		if (_wunlink(_fullname) != 0)
 			IO_EXCEPTION();
@@ -1154,7 +1157,8 @@ utl_file_frename(PG_FUNCTION_ARGS)
 
 	if (!overwrite)
 	{
-		struct stat	st;
+		struct stat st;
+
 		if (stat(dstpath, &st) == 0)
 			CUSTOM_EXCEPTION(WRITE_ERROR, "File exists");
 		else if (errno != ENOENT)
@@ -1169,12 +1173,13 @@ utl_file_frename(PG_FUNCTION_ARGS)
 
 	if (pg_database_encoding_max_length() > 1)
 	{
-		wchar_t	   *_dstpath = to_wchar(dstpath);
-		wchar_t	   *_srcpath = to_wchar(srcpath);
+		wchar_t    *_dstpath = to_wchar(dstpath);
+		wchar_t    *_srcpath = to_wchar(srcpath);
 
 		if (!overwrite)
 		{
-			struct _stat  _st;
+			struct _stat _st;
+
 			if (_wstat(_dstpath, &_st) == 0)
 				CUSTOM_EXCEPTION(WRITE_ERROR, "File exists");
 			else if (errno != ENOENT)
@@ -1182,8 +1187,8 @@ utl_file_frename(PG_FUNCTION_ARGS)
 		}
 
 		/*
-		 * Originaly there was rename() function, but this cannot
-		 * to replace other existing file.
+		 * Originaly there was rename() function, but this cannot to replace
+		 * other existing file.
 		 */
 		if (!MoveFileExW(_srcpath, _dstpath, MOVEFILE_REPLACE_EXISTING))
 			IO_EXCEPTION();
@@ -1195,7 +1200,8 @@ utl_file_frename(PG_FUNCTION_ARGS)
 	{
 		if (!overwrite)
 		{
-			struct stat	st;
+			struct stat st;
+
 			if (stat(dstpath, &st) == 0)
 				CUSTOM_EXCEPTION(WRITE_ERROR, "File exists");
 			else if (errno != ENOENT)
@@ -1242,13 +1248,13 @@ utl_file_fcopy(PG_FUNCTION_ARGS)
 	if (start_line <= 0)
 		ereport(ERROR,
 				(errcode(ERRCODE_INVALID_PARAMETER_VALUE),
-				errmsg("start_line must be positive (%d passed)", start_line)));
+				 errmsg("start_line must be positive (%d passed)", start_line)));
 
 	end_line = PG_GETARG_IF_EXISTS(5, INT32, INT_MAX);
 	if (end_line <= 0)
 		ereport(ERROR,
 				(errcode(ERRCODE_INVALID_PARAMETER_VALUE),
-				errmsg("end_line must be positive (%d passed)", end_line)));
+				 errmsg("end_line must be positive (%d passed)", end_line)));
 
 #ifndef WIN32
 
@@ -1258,8 +1264,8 @@ utl_file_fcopy(PG_FUNCTION_ARGS)
 
 	if (pg_database_encoding_max_length() > 1)
 	{
-		wchar_t	   *_srcpath = to_wchar(srcpath);
-		wchar_t	   *_mode = to_wchar("rt");
+		wchar_t    *_srcpath = to_wchar(srcpath);
+		wchar_t    *_mode = to_wchar("rt");
 
 		srcfile = _wfopen(_srcpath, _mode);
 
@@ -1285,8 +1291,8 @@ utl_file_fcopy(PG_FUNCTION_ARGS)
 
 	if (pg_database_encoding_max_length() > 1)
 	{
-		wchar_t	   *_dstpath = to_wchar(dstpath);
-		wchar_t	   *_mode = to_wchar("wt");
+		wchar_t    *_dstpath = to_wchar(dstpath);
+		wchar_t    *_mode = to_wchar("wt");
 
 		dstfile = _wfopen(_dstpath, _mode);
 
@@ -1337,7 +1343,7 @@ copy_text_file(FILE *srcfile, FILE *dstfile, int start_line, int end_line)
 			if (fgets(buffer, MAX_LINESIZE, srcfile) == NULL)
 				return errno;
 			len = strlen(buffer);
-		} while(buffer[len - 1] != '\n');
+		} while (buffer[len - 1] != '\n');
 	}
 
 	/* copy until end_line. */
@@ -1351,7 +1357,7 @@ copy_text_file(FILE *srcfile, FILE *dstfile, int start_line, int end_line)
 			len = strlen(buffer);
 			if (fwrite(buffer, 1, len, dstfile) != len)
 				return errno;
-		} while(buffer[len - 1] != '\n');
+		} while (buffer[len - 1] != '\n');
 	}
 
 	pfree(buffer);
@@ -1372,12 +1378,12 @@ Datum
 utl_file_fgetattr(PG_FUNCTION_ARGS)
 {
 	char	   *fullname;
-	struct stat	st;
+	struct stat st;
 	TupleDesc	tupdesc;
 	Datum		result;
 	HeapTuple	tuple;
 	Datum		values[3];
-	bool		nulls[3] = { 0 };
+	bool		nulls[3] = {0};
 
 	NOT_NULL_ARG(0);
 	NOT_NULL_ARG(1);
@@ -1407,8 +1413,8 @@ utl_file_fgetattr(PG_FUNCTION_ARGS)
 
 	if (pg_database_encoding_max_length() > 1)
 	{
-		wchar_t	   *_fullname = to_wchar(fullname);
-		struct _stat  _st;
+		wchar_t    *_fullname = to_wchar(fullname);
+		struct _stat _st;
 
 		if (_wstat(_fullname, &_st) == 0)
 		{
@@ -1430,7 +1436,7 @@ utl_file_fgetattr(PG_FUNCTION_ARGS)
 	{
 		values[0] = BoolGetDatum(true);
 		values[1] = Int64GetDatum(st.st_size);
-		values[2] = 512;	/* NTFS block size */
+		values[2] = 512;		/* NTFS block size */
 	}
 	else
 	{
