@@ -79,7 +79,8 @@ PG_FUNCTION_INFO_V1(dbms_pipe_unpack_message_record);
 PG_FUNCTION_INFO_V1(dbms_pipe_pack_message_integer);
 PG_FUNCTION_INFO_V1(dbms_pipe_pack_message_bigint);
 
-typedef enum {
+typedef enum
+{
 	IT_NO_MORE_ITEMS = 0,
 	IT_NUMBER = 9,
 	IT_VARCHAR = 11,
@@ -89,12 +90,14 @@ typedef enum {
 	IT_RECORD = 24
 } message_data_type;
 
-typedef struct _queue_item {
-	void *ptr;
+typedef struct _queue_item
+{
+	void	   *ptr;
 	struct _queue_item *next_item;
-} queue_item;
+}			queue_item;
 
-typedef struct {
+typedef struct
+{
 	long		identity;
 	bool		is_valid;
 	bool		registered;
@@ -108,15 +111,17 @@ typedef struct {
 	int			size;
 } orafce_pipe;
 
-typedef struct {
-	int32 size;
+typedef struct
+{
+	int32		size;
 	message_data_type type;
-	Oid tupType;
+	Oid			tupType;
 } message_data_item;
 
-typedef struct {
-	int32 size;
-	int32 items_count;
+typedef struct
+{
+	int32		size;
+	int32		items_count;
 	message_data_item *next;
 } message_buffer;
 
@@ -129,8 +134,9 @@ typedef struct {
 #define message_data_item_next(msg) \
 	((message_data_item *) (message_data_get_content(msg) + MAXALIGN(msg->size)))
 
-typedef struct PipesFctx {
-	int pipe_nth;
+typedef struct PipesFctx
+{
+	int			pipe_nth;
 } PipesFctx;
 
 typedef struct
@@ -152,7 +158,7 @@ typedef struct
 	size_t		size;
 	int			sid;
 	long		identity_seq;
-	vardata		data[1]; /* flexible array member */
+	vardata		data[1];		/* flexible array member */
 } sh_memory;
 
 #define sh_memory_size			(offsetof(sh_memory, data))
@@ -160,18 +166,18 @@ typedef struct
 static message_buffer *output_buffer = NULL;
 static message_buffer *input_buffer = NULL;
 
-static orafce_pipe* pipes = NULL;
+static orafce_pipe *pipes = NULL;
 
-static long	   *identity_seq = NULL;
+static long *identity_seq = NULL;
 
 #define NOT_INITIALIZED		NULL
 
-LWLockId shmem_lockid = NOT_INITIALIZED;
+LWLockId	shmem_lockid = NOT_INITIALIZED;
 
-int sid;                                 /* session id */
+int			sid;				/* session id */
 
 alert_event *events;
-alert_lock  *locks;
+alert_lock *locks;
 
 #if PG_VERSION_NUM >= 130000
 
@@ -185,7 +191,7 @@ ConditionVariable *alert_cv = NULL;
  */
 static void
 pack_field(message_buffer *buffer, message_data_type type,
-			int32 size, void *ptr, Oid tupType)
+		   int32 size, void *ptr, Oid tupType)
 {
 	int			len;
 	message_data_item *message;
@@ -199,7 +205,7 @@ pack_field(message_buffer *buffer, message_data_type type,
 				 errhint("Increase LOCALMSGSZ in 'pipe.h' and recompile library.")));
 
 	if (buffer->next == NULL)
-		buffer->next =  message_buffer_get_content(buffer);
+		buffer->next = message_buffer_get_content(buffer);
 
 	message = buffer->next;
 
@@ -207,7 +213,10 @@ pack_field(message_buffer *buffer, message_data_type type,
 	message->type = type;
 	message->tupType = tupType;
 
-	/* padding bytes have to be zeroed - buffer creator is responsible to clear memory */
+	/*
+	 * padding bytes have to be zeroed - buffer creator is responsible to
+	 * clear memory
+	 */
 
 	memcpy(message_data_get_content(message), ptr, size);
 
@@ -216,9 +225,9 @@ pack_field(message_buffer *buffer, message_data_type type,
 	buffer->next = message_data_item_next(message);
 }
 
-static void*
+static void *
 unpack_field(message_buffer *buffer, message_data_type *type,
-				int32 *size, Oid *tupType)
+			 int32 *size, Oid *tupType)
 {
 	void	   *ptr;
 	message_data_item *message;
@@ -262,24 +271,34 @@ ora_lock_shmem(size_t size, int max_pipes, int max_events, int max_locks, bool r
 		{
 			int			i;
 
+#if PG_VERSION_NUM >= 190000
+
+			sh_mem->tranche_id = LWLockNewTrancheId("orafce");
+			LWLockInitialize(&sh_mem->shmem_lock, sh_mem->tranche_id);
+
+#else
+
 			sh_mem->tranche_id = LWLockNewTrancheId();
 			LWLockInitialize(&sh_mem->shmem_lock, sh_mem->tranche_id);
 
 			LWLockRegisterTranche(sh_mem->tranche_id, "orafce");
+
+#endif
+
 			shmem_lockid = &sh_mem->shmem_lock;
 
 			sh_mem->identity_seq = 0;
 
 			sh_mem->size = size - sh_memory_size;
 			ora_sinit(sh_mem->data, size, true);
-			pipes = sh_mem->pipes = ora_salloc(max_pipes*sizeof(orafce_pipe));
+			pipes = sh_mem->pipes = ora_salloc(max_pipes * sizeof(orafce_pipe));
 			sid = sh_mem->sid = 1;
 
 			for (i = 0; i < max_pipes; i++)
 				pipes[i].is_valid = false;
 
-			events = sh_mem->events = ora_salloc(max_events*sizeof(alert_event));
-			locks = sh_mem->locks = ora_salloc(max_locks*sizeof(alert_lock));
+			events = sh_mem->events = ora_salloc(max_events * sizeof(alert_event));
+			locks = sh_mem->locks = ora_salloc(max_locks * sizeof(alert_lock));
 
 			for (i = 0; i < max_events; i++)
 			{
@@ -308,7 +327,6 @@ ora_lock_shmem(size_t size, int max_pipes, int max_events, int max_locks, bool r
 		}
 		else
 		{
-			LWLockRegisterTranche(sh_mem->tranche_id, "orafce");
 			shmem_lockid = &sh_mem->shmem_lock;
 
 #if PG_VERSION_NUM >= 130000
@@ -340,9 +358,9 @@ ora_lock_shmem(size_t size, int max_pipes, int max_events, int max_locks, bool r
 /*
  * can be enhanced access/hash.h
  */
-static orafce_pipe*
-find_pipe(text* pipe_name,
-		  bool* created,
+static orafce_pipe *
+find_pipe(text *pipe_name,
+		  bool *created,
 		  bool only_check,
 		  long *expected_identity,
 		  bool *identity_alarm)
@@ -360,7 +378,7 @@ find_pipe(text* pipe_name,
 	for (i = 0; i < MAX_PIPES; i++)
 	{
 		if (pipes[i].is_valid &&
-			strncmp((char*)VARDATA(pipe_name), pipes[i].pipe_name, VARSIZE(pipe_name) - VARHDRSZ) == 0
+			strncmp((char *) VARDATA(pipe_name), pipes[i].pipe_name, VARSIZE(pipe_name) - VARHDRSZ) == 0
 			&& (strlen(pipes[i].pipe_name) == (VARSIZE(pipe_name) - VARHDRSZ)))
 		{
 			if (expected_identity && *expected_identity >= 0
@@ -457,7 +475,7 @@ new_last(orafce_pipe *p, void *ptr, size_t size)
 	return true;
 }
 
-static void*
+static void *
 remove_first(orafce_pipe *p, bool *found)
 {
 	struct _queue_item *q;
@@ -493,7 +511,7 @@ remove_first(orafce_pipe *p, bool *found)
 }
 
 /* copy message to local memory, if exists */
-static message_buffer*
+static message_buffer *
 get_from_pipe(text *pipe_name,
 			  bool *found,
 			  long *identity, bool *identity_alarm)
@@ -515,7 +533,7 @@ get_from_pipe(text *pipe_name,
 			{
 				p->size -= shm_msg->size;
 
-				result = (message_buffer*) MemoryContextAlloc(TopMemoryContext, shm_msg->size);
+				result = (message_buffer *) MemoryContextAlloc(TopMemoryContext, shm_msg->size);
 				memcpy(result, shm_msg, shm_msg->size);
 				ora_sfree(shm_msg);
 			}
@@ -540,7 +558,7 @@ add_to_pipe(text *pipe_name,
 	bool		result = false;
 	message_buffer *sh_ptr;
 
-	if (!ora_lock_shmem(SHMEMMSGSZ, MAX_PIPES, MAX_EVENTS, MAX_LOCKS,false))
+	if (!ora_lock_shmem(SHMEMMSGSZ, MAX_PIPES, MAX_EVENTS, MAX_LOCKS, false))
 		return false;
 
 	for (;;)
@@ -559,7 +577,7 @@ add_to_pipe(text *pipe_name,
 			{
 				if (NULL != (sh_ptr = ora_salloc(ptr->size)))
 				{
-					memcpy(sh_ptr,ptr,ptr->size);
+					memcpy(sh_ptr, ptr, ptr->size);
 					if (new_last(p, sh_ptr, ptr->size))
 					{
 						p->size += ptr->size;
@@ -594,6 +612,7 @@ remove_pipe(text *pipe_name, bool purge)
 	if (NULL != (p = find_pipe(pipe_name, &created, true, NULL, NULL)))
 	{
 		queue_item *q = p->items;
+
 		while (q != NULL)
 		{
 			queue_item *aux_q;
@@ -622,7 +641,7 @@ remove_pipe(text *pipe_name, bool purge)
 }
 
 Datum
-dbms_pipe_next_item_type (PG_FUNCTION_ARGS)
+dbms_pipe_next_item_type(PG_FUNCTION_ARGS)
 {
 	PG_RETURN_INT32(input_buffer != NULL ? input_buffer->next->type : IT_NO_MORE_ITEMS);
 }
@@ -636,12 +655,12 @@ reset_buffer(message_buffer *buffer, int32 size)
 	buffer->next = message_buffer_get_content(buffer);
 }
 
-static message_buffer*
+static message_buffer *
 check_buffer(message_buffer *buffer, int32 size)
 {
 	if (buffer == NULL)
 	{
-		buffer = (message_buffer*) MemoryContextAlloc(TopMemoryContext, size);
+		buffer = (message_buffer *) MemoryContextAlloc(TopMemoryContext, size);
 		if (buffer == NULL)
 			ereport(ERROR,
 					(errcode(ERRCODE_OUT_OF_MEMORY),
@@ -661,7 +680,7 @@ dbms_pipe_pack_message_text(PG_FUNCTION_ARGS)
 
 	output_buffer = check_buffer(output_buffer, LOCALMSGSZ);
 	pack_field(output_buffer, IT_VARCHAR,
-		VARSIZE_ANY_EXHDR(str), VARDATA_ANY(str), InvalidOid);
+			   VARSIZE_ANY_EXHDR(str), VARDATA_ANY(str), InvalidOid);
 
 	PG_RETURN_VOID();
 }
@@ -669,7 +688,7 @@ dbms_pipe_pack_message_text(PG_FUNCTION_ARGS)
 Datum
 dbms_pipe_pack_message_date(PG_FUNCTION_ARGS)
 {
-	DateADT	dt = PG_GETARG_DATEADT(0);
+	DateADT		dt = PG_GETARG_DATEADT(0);
 
 	output_buffer = check_buffer(output_buffer, LOCALMSGSZ);
 	pack_field(output_buffer, IT_DATE,
@@ -693,7 +712,7 @@ dbms_pipe_pack_message_timestamp(PG_FUNCTION_ARGS)
 Datum
 dbms_pipe_pack_message_number(PG_FUNCTION_ARGS)
 {
-	Numeric	num = PG_GETARG_NUMERIC(0);
+	Numeric		num = PG_GETARG_NUMERIC(0);
 
 	output_buffer = check_buffer(output_buffer, LOCALMSGSZ);
 	pack_field(output_buffer, IT_NUMBER,
@@ -709,7 +728,7 @@ dbms_pipe_pack_message_bytea(PG_FUNCTION_ARGS)
 
 	output_buffer = check_buffer(output_buffer, LOCALMSGSZ);
 	pack_field(output_buffer, IT_BYTEA,
-		VARSIZE_ANY_EXHDR(data), VARDATA_ANY(data), InvalidOid);
+			   VARSIZE_ANY_EXHDR(data), VARDATA_ANY(data), InvalidOid);
 
 	PG_RETURN_VOID();
 }
@@ -762,15 +781,15 @@ dbms_pipe_pack_message_record(PG_FUNCTION_ARGS)
 	tupType = HeapTupleHeaderGetTypeId(rec);
 
 	/*
-	 * Normally one would call record_send() using DirectFunctionCall3,
-	 * but that does not work since record_send wants to cache some data
-	 * using fcinfo->flinfo->fn_extra.  So we need to pass it our own
-	 * flinfo parameter.
+	 * Normally one would call record_send() using DirectFunctionCall3, but
+	 * that does not work since record_send wants to cache some data using
+	 * fcinfo->flinfo->fn_extra.  So we need to pass it our own flinfo
+	 * parameter.
 	 */
 	InitFunctionCallInfoData(*info, fcinfo->flinfo, 3, InvalidOid, NULL, NULL);
 	init_args_3(info, PointerGetDatum(rec), ObjectIdGetDatum(tupType), Int32GetDatum(-1));
 
-	data = (bytea*) DatumGetPointer(record_send(info));
+	data = (bytea *) DatumGetPointer(record_send(info));
 
 	output_buffer = check_buffer(output_buffer, LOCALMSGSZ);
 	pack_field(output_buffer, IT_RECORD,
@@ -808,10 +827,10 @@ dbms_pipe_unpack_message(PG_FUNCTION_ARGS, message_data_type dtype)
 	switch (type)
 	{
 		case IT_TIMESTAMPTZ:
-			result = TimestampTzGetDatum(*(TimestampTz*)ptr);
+			result = TimestampTzGetDatum(*(TimestampTz *) ptr);
 			break;
 		case IT_DATE:
-			result = DateADTGetDatum(*(DateADT*)ptr);
+			result = DateADTGetDatum(*(DateADT *) ptr);
 			break;
 		case IT_VARCHAR:
 		case IT_NUMBER:
@@ -819,41 +838,42 @@ dbms_pipe_unpack_message(PG_FUNCTION_ARGS, message_data_type dtype)
 			result = PointerGetDatum(cstring_to_text_with_len(ptr, size));
 			break;
 		case IT_RECORD:
-		{
+			{
 #if PG_VERSION_NUM >= 120000
 
-			LOCAL_FCINFO(info, 3);
+				LOCAL_FCINFO(info, 3);
 
 #else
 
-			FunctionCallInfoData info_data;
-			FunctionCallInfo info = &info_data;
+				FunctionCallInfoData info_data;
+				FunctionCallInfo info = &info_data;
 
 #endif
 
-			StringInfoData	buf;
-			text		   *data = cstring_to_text_with_len(ptr, size);
+				StringInfoData buf;
+				text	   *data = cstring_to_text_with_len(ptr, size);
 
-			buf.data = VARDATA(data);
-			buf.len = VARSIZE(data) - VARHDRSZ;
-			buf.maxlen = buf.len;
-			buf.cursor = 0;
+				buf.data = VARDATA(data);
+				buf.len = VARSIZE(data) - VARHDRSZ;
+				buf.maxlen = buf.len;
+				buf.cursor = 0;
 
-			/*
-			 * Normally one would call record_recv() using DirectFunctionCall3,
-			 * but that does not work since record_recv wants to cache some data
-			 * using fcinfo->flinfo->fn_extra.  So we need to pass it our own
-			 * flinfo parameter.
-			 */
-			InitFunctionCallInfoData(*info, fcinfo->flinfo, 3, InvalidOid, NULL, NULL);
-			init_args_3(info, PointerGetDatum(&buf), ObjectIdGetDatum(tupType), Int32GetDatum(-1));
+				/*
+				 * Normally one would call record_recv() using
+				 * DirectFunctionCall3, but that does not work since
+				 * record_recv wants to cache some data using
+				 * fcinfo->flinfo->fn_extra.  So we need to pass it our own
+				 * flinfo parameter.
+				 */
+				InitFunctionCallInfoData(*info, fcinfo->flinfo, 3, InvalidOid, NULL, NULL);
+				init_args_3(info, PointerGetDatum(&buf), ObjectIdGetDatum(tupType), Int32GetDatum(-1));
 
-			result = record_recv(info);
-			break;
-		}
+				result = record_recv(info);
+				break;
+			}
 		default:
 			elog(ERROR, "unexpected type: %d", type);
-			result = (Datum) 0;	/* keep compiler quiet */
+			result = (Datum) 0; /* keep compiler quiet */
 	}
 
 	if (input_buffer->items_count == 0)
@@ -995,8 +1015,8 @@ dbms_pipe_receive_message(PG_FUNCTION_ARGS)
 #if PG_VERSION_NUM >= 130000
 
 			/*
-			 * Timeout should be less than INT_MAX, but we set 1 sec as protection
-			 * against deadlocks.
+			 * Timeout should be less than INT_MAX, but we set 1 sec as
+			 * protection against deadlocks.
 			 */
 			if (cur_timeout > 1000)
 				cur_timeout = 1000;
@@ -1186,12 +1206,12 @@ dbms_pipe_unique_session_name(PG_FUNCTION_ARGS)
 	int			timeout = 10;
 
 	WATCH_PRE(timeout, endtime, cycle);
-	if (ora_lock_shmem(SHMEMMSGSZ, MAX_PIPES,MAX_EVENTS,MAX_LOCKS,false))
+	if (ora_lock_shmem(SHMEMMSGSZ, MAX_PIPES, MAX_EVENTS, MAX_LOCKS, false))
 	{
 		text	   *result;
 
 		initStringInfo(&strbuf);
-		appendStringInfo(&strbuf,"PG$PIPE$%d$%d",sid, MyProcPid);
+		appendStringInfo(&strbuf, "PG$PIPE$%d$%d", sid, MyProcPid);
 
 		result = cstring_to_text_with_len(strbuf.data, strbuf.len);
 		pfree(strbuf.data);
@@ -1220,9 +1240,9 @@ dbms_pipe_list_pipes(PG_FUNCTION_ARGS)
 
 	if (SRF_IS_FIRSTCALL())
 	{
-		int		i;
-		MemoryContext  oldcontext;
-		bool has_lock = false;
+		int			i;
+		MemoryContext oldcontext;
+		bool		has_lock = false;
 
 		WATCH_PRE(timeout, endtime, cycle);
 		if (ora_lock_shmem(SHMEMMSGSZ, MAX_PIPES, MAX_EVENTS, MAX_LOCKS, false))
@@ -1252,12 +1272,12 @@ dbms_pipe_list_pipes(PG_FUNCTION_ARGS)
 #endif
 
 		i = 0;
-		TupleDescInitEntry(tupdesc, ++i, "name",    VARCHAROID, -1, 0);
-		TupleDescInitEntry(tupdesc, ++i, "items",   INT4OID,    -1, 0);
-		TupleDescInitEntry(tupdesc, ++i, "size",    INT4OID,    -1, 0);
-		TupleDescInitEntry(tupdesc, ++i, "limit",   INT4OID,    -1, 0);
-		TupleDescInitEntry(tupdesc, ++i, "private", BOOLOID,    -1, 0);
-		TupleDescInitEntry(tupdesc, ++i, "owner",   VARCHAROID, -1, 0);
+		TupleDescInitEntry(tupdesc, ++i, "name", VARCHAROID, -1, 0);
+		TupleDescInitEntry(tupdesc, ++i, "items", INT4OID, -1, 0);
+		TupleDescInitEntry(tupdesc, ++i, "size", INT4OID, -1, 0);
+		TupleDescInitEntry(tupdesc, ++i, "limit", INT4OID, -1, 0);
+		TupleDescInitEntry(tupdesc, ++i, "private", BOOLOID, -1, 0);
+		TupleDescInitEntry(tupdesc, ++i, "owner", VARCHAROID, -1, 0);
 		Assert(i == DB_PIPES_COLS);
 
 		attinmeta = TupleDescGetAttInMetadata(tupdesc);
@@ -1351,9 +1371,10 @@ dbms_pipe_create_pipe(PG_FUNCTION_ARGS)
 	is_private = PG_ARGISNULL(2) ? false : PG_GETARG_BOOL(2);
 
 	WATCH_PRE(timeout, endtime, cycle);
-	if (ora_lock_shmem(SHMEMMSGSZ, MAX_PIPES,MAX_EVENTS,MAX_LOCKS,false))
+	if (ora_lock_shmem(SHMEMMSGSZ, MAX_PIPES, MAX_EVENTS, MAX_LOCKS, false))
 	{
 		orafce_pipe *p;
+
 		if (NULL != (p = find_pipe(pipe_name, &created, false, NULL, NULL)))
 		{
 			if (!created)
@@ -1369,8 +1390,8 @@ dbms_pipe_create_pipe(PG_FUNCTION_ARGS)
 
 				p->uid = GetUserId();
 
-				user = (char*)DirectFunctionCall1(namein,
-					    CStringGetDatum(GetUserNameFromId(p->uid, false)));
+				user = (char *) DirectFunctionCall1(namein,
+													CStringGetDatum(GetUserNameFromId(p->uid, false)));
 
 				p->creator = ora_sstrcpy(user);
 				pfree(user);
@@ -1422,7 +1443,7 @@ dbms_pipe_purge(PG_FUNCTION_ARGS)
 	int			timeout = 10;
 
 	WATCH_PRE(timeout, endtime, cycle);
-	if (ora_lock_shmem(SHMEMMSGSZ, MAX_PIPES,MAX_EVENTS,MAX_LOCKS,false))
+	if (ora_lock_shmem(SHMEMMSGSZ, MAX_PIPES, MAX_EVENTS, MAX_LOCKS, false))
 	{
 
 		remove_pipe(pipe_name, true);
@@ -1454,7 +1475,7 @@ dbms_pipe_remove_pipe(PG_FUNCTION_ARGS)
 	int			timeout = 10;
 
 	WATCH_PRE(timeout, endtime, cycle);
-	if (ora_lock_shmem(SHMEMMSGSZ, MAX_PIPES,MAX_EVENTS,MAX_LOCKS,false))
+	if (ora_lock_shmem(SHMEMMSGSZ, MAX_PIPES, MAX_EVENTS, MAX_LOCKS, false))
 	{
 		remove_pipe(pipe_name, false);
 		LWLockRelease(shmem_lockid);
@@ -1479,8 +1500,8 @@ dbms_pipe_remove_pipe(PG_FUNCTION_ARGS)
 Datum
 dbms_pipe_create_pipe_2(PG_FUNCTION_ARGS)
 {
-	Datum	arg1;
-	int		limit = -1;
+	Datum		arg1;
+	int			limit = -1;
 
 	if (PG_ARGISNULL(0))
 		ereport(ERROR,
@@ -1504,7 +1525,7 @@ dbms_pipe_create_pipe_2(PG_FUNCTION_ARGS)
 Datum
 dbms_pipe_create_pipe_1(PG_FUNCTION_ARGS)
 {
-	Datum	arg1;
+	Datum		arg1;
 
 	if (PG_ARGISNULL(0))
 		ereport(ERROR,
@@ -1527,7 +1548,7 @@ dbms_pipe_pack_message_integer(PG_FUNCTION_ARGS)
 {
 	/* Casting from int4 to numeric */
 	DirectFunctionCall1(dbms_pipe_pack_message_number,
-				DirectFunctionCall1(int4_numeric, PG_GETARG_DATUM(0)));
+						DirectFunctionCall1(int4_numeric, PG_GETARG_DATUM(0)));
 
 	PG_RETURN_VOID();
 }
@@ -1537,7 +1558,7 @@ dbms_pipe_pack_message_bigint(PG_FUNCTION_ARGS)
 {
 	/* Casting from int8 to numeric */
 	DirectFunctionCall1(dbms_pipe_pack_message_number,
-				DirectFunctionCall1(int8_numeric, PG_GETARG_DATUM(0)));
+						DirectFunctionCall1(int8_numeric, PG_GETARG_DATUM(0)));
 
 	PG_RETURN_VOID();
 }
